@@ -64,13 +64,13 @@ def get_running_players():
 		if p.is_running():
 			running.append(p)
 	
-	for p in _get_mpris_players():
-		running.append(p)
-	
-	return running
+	return running + _get_mpris_players()
 
 def get_player(player_id):
-	"""Returns a player object if the player's running. None otherwise."""
+	"""
+		Returns a player object if the player's running
+		None otherwise
+	"""
 	
 	for player in get_running_players():
 		if player.get_id() == player_id:
