@@ -43,6 +43,9 @@ class PlayerBase(object):
 	def __repr__(self):
 		return self.get_name()
 	
+	def __hash__(self):
+		return hash(self.get_id())
+	
 	def get_track(self):
 		return NotImplemented
 	
@@ -89,3 +92,14 @@ class PlayerBase(object):
 				"is_playing": self.is_playing(),
 				"player_id": self.get_id(),
 				}
+
+def silent(funct):
+	"""a descriptor"""
+	
+	def r(*args):
+		try:
+			return funct(*args)
+		except:
+			return None
+	
+	return r
